@@ -1,5 +1,43 @@
 var NAVTREEINDEX16 =
 {
+"page_examples.html":[7,7],
+"page_library.html":[5,9],
+"page_library.html#autotoc_md45":[5,9,0],
+"page_library.html#autotoc_md46":[5,9,1],
+"page_library.html#autotoc_md47":[5,9,2],
+"page_library.html#autotoc_md48":[5,9,3],
+"page_library.html#autotoc_md49":[5,9,3,0],
+"page_library.html#autotoc_md50":[5,9,3,1],
+"page_library.html#autotoc_md51":[5,9,3,2],
+"page_library.html#autotoc_md52":[5,9,3,3],
+"page_library.html#autotoc_md53":[5,9,3,4],
+"page_library.html#autotoc_md54":[5,9,3,5],
+"page_library.html#autotoc_md55":[5,9,3,6],
+"page_library.html#autotoc_md56":[5,9,3,7],
+"page_library.html#autotoc_md57":[5,9,3,8],
+"page_library.html#autotoc_md58":[5,9,3,9],
+"page_library.html#autotoc_md59":[5,9,4],
+"page_library.html#autotoc_md60":[5,9,4,0],
+"page_library.html#autotoc_md61":[5,9,4,1],
+"page_library.html#autotoc_md62":[5,9,5],
+"page_library.html#autotoc_md63":[5,9,6],
+"page_library.html#autotoc_md64":[5,9,7],
+"page_man_pipewire_1.html":[5,14,0],
+"page_man_pipewire_conf_5.html":[5,14,2],
+"page_man_pipewire_pulse_1.html":[5,14,1],
+"page_man_pw_cat_1.html":[5,14,3],
+"page_man_pw_cli_1.html":[5,14,4],
+"page_man_pw_config_1.html":[5,14,5],
+"page_man_pw_dot_1.html":[5,14,6],
+"page_man_pw_jack_1.html":[5,14,13],
+"page_man_pw_link_1.html":[5,14,7],
+"page_man_pw_metadata_1.html":[5,14,8],
+"page_man_pw_mididump_1.html":[5,14,9],
+"page_man_pw_mon_1.html":[5,14,10],
+"page_man_pw_profiler_1.html":[5,14,11],
+"page_man_pw_top_1.html":[5,14,12],
+"page_midi.html":[5,7],
+"page_midi.html#autotoc_md20":[5,7,0],
 "page_midi.html#autotoc_md21":[5,7,0,0],
 "page_midi.html#autotoc_md22":[5,7,0,1],
 "page_midi.html#autotoc_md23":[5,7,0,2],
@@ -49,8 +87,10 @@ var NAVTREEINDEX16 =
 "page_module_rtp_sink.html":[6,32],
 "page_module_rtp_source.html":[6,33],
 "page_module_session_manager.html":[6,36],
-"page_module_x11_bell.html":[6,37],
-"page_module_zeroconf_discover.html":[6,38],
+"page_module_vban_recv.html":[6,37],
+"page_module_vban_send.html":[6,38],
+"page_module_x11_bell.html":[6,39],
+"page_module_zeroconf_discover.html":[6,40],
 "page_native_protocol.html":[5,12],
 "page_native_protocol.html#autotoc_md116":[5,12,0],
 "page_native_protocol.html#autotoc_md117":[5,12,1],
@@ -209,45 +249,5 @@ var NAVTREEINDEX16 =
 "page_proxy.html#sec_page_proxy_methods":[8,1,4],
 "page_proxy.html#sec_page_proxy_overview":[8,1,0],
 "page_pulseaudio.html":[5,16],
-"page_pulseaudio.html#autotoc_md281":[5,16,0],
-"page_pulseaudio.html#autotoc_md282":[5,16,0,0],
-"page_pulseaudio.html#autotoc_md283":[5,16,0,1],
-"page_pulseaudio.html#autotoc_md284":[5,16,1],
-"page_pulseaudio.html#autotoc_md285":[5,16,1,0],
-"page_pulseaudio.html#autotoc_md286":[5,16,1,1],
-"page_pulseaudio.html#autotoc_md287":[5,16,1,2],
-"page_pulseaudio.html#autotoc_md288":[5,16,1,3],
-"page_pulseaudio.html#autotoc_md289":[5,16,2],
-"page_scheduling.html":[5,11],
-"page_scheduling.html#autotoc_md108":[5,11,0],
-"page_scheduling.html#autotoc_md109":[5,11,1],
-"page_scheduling.html#autotoc_md110":[5,11,2],
-"page_scheduling.html#autotoc_md111":[5,11,2,0],
-"page_scheduling.html#autotoc_md112":[5,11,2,1],
-"page_scheduling.html#autotoc_md113":[5,11,2,2],
-"page_scheduling.html#autotoc_md114":[5,11,3],
-"page_scheduling.html#autotoc_md115":[5,11,3,0],
-"page_session_manager.html":[5,15],
-"page_session_manager.html#autotoc_md65":[5,15,0],
-"page_session_manager.html#autotoc_md66":[5,15,1],
-"page_session_manager.html#autotoc_md67":[5,15,2],
-"page_spa.html":[9],
-"page_spa.html#autotoc_md223":[9,0],
-"page_spa.html#autotoc_md224":[9,1],
-"page_spa.html#autotoc_md225":[9,2],
-"page_spa.html#autotoc_md226":[9,3],
-"page_spa_buffer.html":[9,7],
-"page_spa_design.html":[9,4],
-"page_spa_design.html#autotoc_md239":[9,4,0],
-"page_spa_design.html#autotoc_md240":[9,4,0,0],
-"page_spa_design.html#autotoc_md241":[9,4,0,1],
-"page_spa_design.html#autotoc_md242":[9,4,0,2],
-"page_spa_plugins.html":[9,5],
-"page_spa_plugins.html#autotoc_md227":[9,5,0],
-"page_spa_plugins.html#autotoc_md228":[9,5,1],
-"page_spa_plugins.html#autotoc_md229":[9,5,2],
-"page_spa_plugins.html#autotoc_md230":[9,5,3],
-"page_spa_plugins.html#autotoc_md231":[9,5,4],
-"page_spa_plugins.html#autotoc_md232":[9,5,5],
-"page_spa_plugins.html#autotoc_md233":[9,5,6]
+"page_pulseaudio.html#autotoc_md281":[5,16,0]
 };
