@@ -1,5 +1,46 @@
 var NAVTREEINDEX21 =
 {
+"structspa__dict.html":[10,8,8,2,2],
+"structspa__dict.html#a1f1083da3fcd51b9c3eb22cc8f1d54e0":[10,8,8,2,2,2],
+"structspa__dict.html#a3b3b78bfe5fffe13a10720bb7099c399":[10,8,8,2,2,1],
+"structspa__dict.html#a88aca003fcdbc47599ffb3e2737f1a69":[10,8,8,2,2,0],
+"structspa__dict__item.html":[10,8,8,2,1],
+"structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[10,8,8,2,1,0],
+"structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[10,8,8,2,1,1],
+"structspa__dll.html":[11,0,180],
+"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,180,2],
+"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,180,1],
+"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,180,6],
+"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,180,3],
+"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,180,4],
+"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,180,0],
+"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,180,5],
+"structspa__event.html":[10,8,0,15],
+"structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[10,8,0,15,1],
+"structspa__event.html#a2411141eed88d3587687a8d86c99d488":[10,8,0,15,0],
+"structspa__event__body.html":[10,8,0,14],
+"structspa__event__body.html#aa484bc2cadd16a104476183666de3819":[10,8,0,14,0],
+"structspa__fraction.html":[10,8,8,1,4],
+"structspa__fraction.html#a55246db96d647cd96be18983d59feb56":[10,8,8,1,4,0],
+"structspa__fraction.html#af099fb3a18c93ddac10239564da9de0c":[10,8,8,1,4,1],
+"structspa__graph.html":[10,8,5,3],
+"structspa__graph.html#a850c90822a1b32d7cd67ec5c76eda2fa":[10,8,5,3,0],
+"structspa__graph.html#a90439529765f13aadc6f1d7727244a1c":[10,8,5,3,3],
+"structspa__graph.html#a9bcd83554b53da4a139ed6a9be38bb1c":[10,8,5,3,1],
+"structspa__graph.html#aacd6dde80b95c6415d300f419ea6f144":[10,8,5,3,2],
+"structspa__graph__link.html":[10,8,5,2],
+"structspa__graph__link.html#a15313bfb8509b74448784ebf30f191c6":[10,8,5,2,1],
+"structspa__graph__link.html#ab1f910424f6a5ea5a34b52695536f53d":[10,8,5,2,0],
+"structspa__graph__link.html#ab7c807f9aaa9242cf8573b13212de674":[10,8,5,2,2],
+"structspa__graph__link.html#abf9a5059f5b888cf3a331832830f7373":[10,8,5,2,3],
+"structspa__graph__node.html":[10,8,5,5],
+"structspa__graph__node.html#a23c316f71a255a568e96092e72c40cae":[10,8,5,5,4],
+"structspa__graph__node.html#a6215edd0d426cfc8e697d648c09a4f57":[10,8,5,5,0],
+"structspa__graph__node.html#a6664b3c60baddc151a340bf2ebb3a5a2":[10,8,5,5,8],
+"structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740":[10,8,5,5,1],
+"structspa__graph__node.html#ab16592a35d02f827271786b49110341c":[10,8,5,5,7],
+"structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0":[10,8,5,5,6],
+"structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[10,8,5,5,3],
 "structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c":[10,8,5,5,5],
 "structspa__graph__node.html#aec1169015c1d7a4aaea10d5f4946f7d4":[10,8,5,5,2],
 "structspa__graph__node.html#af4ae9586aa3d544a48414987f1839a67":[10,8,5,5,9],
@@ -53,6 +94,7 @@ var NAVTREEINDEX21 =
 "structspa__io__clock.html":[10,8,6,9],
 "structspa__io__clock.html#a02274245ac560717fc5c06ddc66553ff":[10,8,6,9,9],
 "structspa__io__clock.html#a3242b88552347adc2e406b75f8136060":[10,8,6,9,8],
+"structspa__io__clock.html#a3dc77892eea443b66c01d2acc91acaeb":[10,8,6,9,13],
 "structspa__io__clock.html#a4813e6c9101d56eb1f3ac2e9eda1d8c8":[10,8,6,9,4],
 "structspa__io__clock.html#a726264b491673c896b53038752149ecb":[10,8,6,9,2],
 "structspa__io__clock.html#a96d1fa8bd97bb1a840403a103853673e":[10,8,6,9,3],
@@ -60,7 +102,7 @@ var NAVTREEINDEX21 =
 "structspa__io__clock.html#ab3d44cc4e16a47abd913553c3b977051":[10,8,6,9,0],
 "structspa__io__clock.html#ab639d1a64a22eecfa76ca04001bc163d":[10,8,6,9,1],
 "structspa__io__clock.html#ad5f6c0254efd87a20ca5807b577d3473":[10,8,6,9,10],
-"structspa__io__clock.html#ade3b0ef4306272d9a83a361ac3312cad":[10,8,6,9,12],
+"structspa__io__clock.html#add07660ad1ad6f6951596c5a0422cd9b":[10,8,6,9,12],
 "structspa__io__clock.html#af384237834c65792f29ccfd3fadfeefe":[10,8,6,9,5],
 "structspa__io__clock.html#af8fa38eef9a514c13306bd01da06e776":[10,8,6,9,6],
 "structspa__io__clock.html#af91526e984d8c9453e8b98c12dd1f500":[10,8,6,9,11],
@@ -129,14 +171,14 @@ var NAVTREEINDEX21 =
 "structspa__json.html#a8a0962e6aafa40f4b0124bcbb94e04df":[10,8,8,6,1,3],
 "structspa__json.html#a8c09dbf1f541a944ceef31cb0b4110af":[10,8,8,6,1,1],
 "structspa__json.html#ae765edf5a3ac4c7fe5be87c93f62b0c2":[10,8,8,6,1,2],
-"structspa__latency__info.html":[10,8,7,38],
-"structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101":[10,8,7,38,3],
-"structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec":[10,8,7,38,4],
-"structspa__latency__info.html#a9b3d5d2e366d8081d91adcf736b15c48":[10,8,7,38,0],
-"structspa__latency__info.html#aab5617769d3799f99a80747917268db8":[10,8,7,38,2],
-"structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725":[10,8,7,38,1],
-"structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b":[10,8,7,38,5],
-"structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e":[10,8,7,38,6],
+"structspa__latency__info.html":[10,8,7,40],
+"structspa__latency__info.html#a114447a982c76675818ca5fff6e5b101":[10,8,7,40,3],
+"structspa__latency__info.html#a7950ed27a0b4e341e1c852fb5ca6e4ec":[10,8,7,40,4],
+"structspa__latency__info.html#a9b3d5d2e366d8081d91adcf736b15c48":[10,8,7,40,0],
+"structspa__latency__info.html#aab5617769d3799f99a80747917268db8":[10,8,7,40,2],
+"structspa__latency__info.html#aadaa9a123ffe5f4a050945e210cc5725":[10,8,7,40,1],
+"structspa__latency__info.html#ac9e3498891f63e0c2f6e6df171febb5b":[10,8,7,40,5],
+"structspa__latency__info.html#ae4923a45e4de7d99b8aa658c4e59235e":[10,8,7,40,6],
 "structspa__list.html":[10,8,8,3,1],
 "structspa__list.html#ab67df98c96319f199a02cb48ee7de93e":[10,8,8,3,1,1],
 "structspa__list.html#aed4aa24d6a3d4f62a4198296312a6196":[10,8,8,3,1,0],
@@ -207,47 +249,5 @@ var NAVTREEINDEX21 =
 "structspa__meta__control.html#a906715cf9e6709fcd23de4aef7c1dd4a":[10,8,1,13,0],
 "structspa__meta__cursor.html":[10,8,1,12],
 "structspa__meta__cursor.html#a01ee3f6baba19d1a0851a44badd819a9":[10,8,1,12,1],
-"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028":[10,8,1,12,3],
-"structspa__meta__cursor.html#a5f190ab6e828890a8c5b530cb9cae78d":[10,8,1,12,0],
-"structspa__meta__cursor.html#a78b7805e66e52164fc8a985578b4c990":[10,8,1,12,2],
-"structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0":[10,8,1,12,4],
-"structspa__meta__header.html":[10,8,1,9],
-"structspa__meta__header.html#a1410208fd9ccdd153418f01d5ce12d7b":[10,8,1,9,1],
-"structspa__meta__header.html#a2d8eed1753e4b1649faf357f3307217d":[10,8,1,9,0],
-"structspa__meta__header.html#a76604c6ef39f2e3f103f6e71532205c8":[10,8,1,9,4],
-"structspa__meta__header.html#aae54e5badad1945c2a49d64842df5b1f":[10,8,1,9,2],
-"structspa__meta__header.html#af9dface8f9e761dc4025dceaa4527a45":[10,8,1,9,3],
-"structspa__meta__region.html":[10,8,1,10],
-"structspa__meta__region.html#af1fe3dd2f5fc8f7e8899b93049dfffd2":[10,8,1,10,0],
-"structspa__meta__videotransform.html":[10,8,1,15],
-"structspa__meta__videotransform.html#a92c7c86c35c37a1d7cd7f9b79b99ef6d":[10,8,1,15,0],
-"structspa__node.html":[10,8,6,18],
-"structspa__node.html#a898fcb8b2d37d7c42fd9c15d1f8c1ed7":[10,8,6,18,0],
-"structspa__node__callbacks.html":[10,8,6,24],
-"structspa__node__callbacks.html#a249a8d683dc8b92cdca1c0b9eed75d4d":[10,8,6,24,0],
-"structspa__node__callbacks.html#a2e4fa7f89e8c1d306d44569191c44311":[10,8,6,24,1],
-"structspa__node__callbacks.html#a48ef28f7570e07dbfb45fdb247e02671":[10,8,6,24,2],
-"structspa__node__callbacks.html#a597eb6e41252d8030e4d697b51406ad0":[10,8,6,24,3],
-"structspa__node__events.html":[10,8,6,23],
-"structspa__node__events.html#a37b6ed18688f456b4c4e9b157879414f":[10,8,6,23,0],
-"structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741":[10,8,6,23,4],
-"structspa__node__events.html#a64cd08176057e03e97babf5b36ecd7bf":[10,8,6,23,3],
-"structspa__node__events.html#a6950a2df9f758cbbe7651f9db3962bed":[10,8,6,23,1],
-"structspa__node__events.html#a7915d7cc4ad14d41c0a0865798470429":[10,8,6,23,2],
-"structspa__node__info.html":[10,8,6,19],
-"structspa__node__info.html#a11fa9f260086bf624de400a80bf79219":[10,8,6,19,4],
-"structspa__node__info.html#a248c6cf0005c3b29a3ceb1bbff232cd9":[10,8,6,19,3],
-"structspa__node__info.html#a41964dbf3b7ace8dd61b9f82d123b4d6":[10,8,6,19,5],
-"structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5":[10,8,6,19,1],
-"structspa__node__info.html#a985458f3b046fb6b7da0974ac08fe504":[10,8,6,19,2],
-"structspa__node__info.html#a9f05f762157f2ae9db446937f19da173":[10,8,6,19,0],
-"structspa__node__methods.html":[10,8,6,25],
-"structspa__node__methods.html#a0ea59a508f6d40b5889c23940a036be6":[10,8,6,25,5],
-"structspa__node__methods.html#a1f465eba7a1322ef153142227a68d43b":[10,8,6,25,10],
-"structspa__node__methods.html#a2089aa56468969fa4e6e65d6c80dbd14":[10,8,6,25,13],
-"structspa__node__methods.html#a2216e9265fde3d179e7bec8ae69baecc":[10,8,6,25,15],
-"structspa__node__methods.html#a2773ceced2814d3adec184fa5ad538d2":[10,8,6,25,12],
-"structspa__node__methods.html#a2bb8310a8ab8273ac0f53b54c6b23223":[10,8,6,25,1],
-"structspa__node__methods.html#a3d23d14b7707fc2f3926a78d47dde720":[10,8,6,25,3],
-"structspa__node__methods.html#a7236a06df9ca3894d3164b7b0566cc54":[10,8,6,25,8]
+"structspa__meta__cursor.html#a46bdd5e6f3d880a74ae602e596176028":[10,8,1,12,3]
 };
