@@ -1,5 +1,47 @@
 var NAVTREEINDEX22 =
 {
+"structspa__meta__cursor.html#a5f190ab6e828890a8c5b530cb9cae78d":[10,8,1,12,0],
+"structspa__meta__cursor.html#a78b7805e66e52164fc8a985578b4c990":[10,8,1,12,2],
+"structspa__meta__cursor.html#a9785c5b1408d2d4c4cc053bfb67ef6c0":[10,8,1,12,4],
+"structspa__meta__header.html":[10,8,1,9],
+"structspa__meta__header.html#a1410208fd9ccdd153418f01d5ce12d7b":[10,8,1,9,1],
+"structspa__meta__header.html#a2d8eed1753e4b1649faf357f3307217d":[10,8,1,9,0],
+"structspa__meta__header.html#a76604c6ef39f2e3f103f6e71532205c8":[10,8,1,9,4],
+"structspa__meta__header.html#aae54e5badad1945c2a49d64842df5b1f":[10,8,1,9,2],
+"structspa__meta__header.html#af9dface8f9e761dc4025dceaa4527a45":[10,8,1,9,3],
+"structspa__meta__region.html":[10,8,1,10],
+"structspa__meta__region.html#af1fe3dd2f5fc8f7e8899b93049dfffd2":[10,8,1,10,0],
+"structspa__meta__videotransform.html":[10,8,1,15],
+"structspa__meta__videotransform.html#a92c7c86c35c37a1d7cd7f9b79b99ef6d":[10,8,1,15,0],
+"structspa__node.html":[10,8,6,18],
+"structspa__node.html#a898fcb8b2d37d7c42fd9c15d1f8c1ed7":[10,8,6,18,0],
+"structspa__node__callbacks.html":[10,8,6,24],
+"structspa__node__callbacks.html#a249a8d683dc8b92cdca1c0b9eed75d4d":[10,8,6,24,0],
+"structspa__node__callbacks.html#a2e4fa7f89e8c1d306d44569191c44311":[10,8,6,24,1],
+"structspa__node__callbacks.html#a48ef28f7570e07dbfb45fdb247e02671":[10,8,6,24,2],
+"structspa__node__callbacks.html#a597eb6e41252d8030e4d697b51406ad0":[10,8,6,24,3],
+"structspa__node__events.html":[10,8,6,23],
+"structspa__node__events.html#a37b6ed18688f456b4c4e9b157879414f":[10,8,6,23,0],
+"structspa__node__events.html#a4b3918e0034bb87549fe911028ca8741":[10,8,6,23,4],
+"structspa__node__events.html#a64cd08176057e03e97babf5b36ecd7bf":[10,8,6,23,3],
+"structspa__node__events.html#a6950a2df9f758cbbe7651f9db3962bed":[10,8,6,23,1],
+"structspa__node__events.html#a7915d7cc4ad14d41c0a0865798470429":[10,8,6,23,2],
+"structspa__node__info.html":[10,8,6,19],
+"structspa__node__info.html#a11fa9f260086bf624de400a80bf79219":[10,8,6,19,4],
+"structspa__node__info.html#a248c6cf0005c3b29a3ceb1bbff232cd9":[10,8,6,19,3],
+"structspa__node__info.html#a41964dbf3b7ace8dd61b9f82d123b4d6":[10,8,6,19,5],
+"structspa__node__info.html#a5c181a5c275e9a0c9ec82156a38f10a5":[10,8,6,19,1],
+"structspa__node__info.html#a985458f3b046fb6b7da0974ac08fe504":[10,8,6,19,2],
+"structspa__node__info.html#a9f05f762157f2ae9db446937f19da173":[10,8,6,19,0],
+"structspa__node__methods.html":[10,8,6,25],
+"structspa__node__methods.html#a0ea59a508f6d40b5889c23940a036be6":[10,8,6,25,5],
+"structspa__node__methods.html#a1f465eba7a1322ef153142227a68d43b":[10,8,6,25,10],
+"structspa__node__methods.html#a2089aa56468969fa4e6e65d6c80dbd14":[10,8,6,25,13],
+"structspa__node__methods.html#a2216e9265fde3d179e7bec8ae69baecc":[10,8,6,25,15],
+"structspa__node__methods.html#a2773ceced2814d3adec184fa5ad538d2":[10,8,6,25,12],
+"structspa__node__methods.html#a2bb8310a8ab8273ac0f53b54c6b23223":[10,8,6,25,1],
+"structspa__node__methods.html#a3d23d14b7707fc2f3926a78d47dde720":[10,8,6,25,3],
+"structspa__node__methods.html#a7236a06df9ca3894d3164b7b0566cc54":[10,8,6,25,8],
 "structspa__node__methods.html#a788f398e8fa5e85f03ecb68602821204":[10,8,6,25,4],
 "structspa__node__methods.html#a8b0809c0e27afae1c9489bc5807e4cb7":[10,8,6,25,2],
 "structspa__node__methods.html#a9b95b184ba04c05972ca57c1ae16c346":[10,8,6,25,0],
@@ -8,12 +50,12 @@ var NAVTREEINDEX22 =
 "structspa__node__methods.html#ac43bffc3912889ba2c35c8fe7c7142db":[10,8,6,25,9],
 "structspa__node__methods.html#accf0d924064ab5c9c1cdde7d0013232c":[10,8,6,25,7],
 "structspa__node__methods.html#af04906b32eb2e2862e8e2e2b0ef71f0c":[10,8,6,25,11],
-"structspa__param__info.html":[10,8,7,40],
-"structspa__param__info.html#a1fcfd641de4a963a797da64eebfe7771":[10,8,7,40,1],
-"structspa__param__info.html#a76f02e8ac2d41d1fc75fb734ad94af1c":[10,8,7,40,4],
-"structspa__param__info.html#aafe96bbf409564bcce653d58fffb40cf":[10,8,7,40,2],
-"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe":[10,8,7,40,0],
-"structspa__param__info.html#afcbe452106c79a62cc457da5a19eafcb":[10,8,7,40,3],
+"structspa__param__info.html":[10,8,7,42],
+"structspa__param__info.html#a1fcfd641de4a963a797da64eebfe7771":[10,8,7,42,1],
+"structspa__param__info.html#a76f02e8ac2d41d1fc75fb734ad94af1c":[10,8,7,42,4],
+"structspa__param__info.html#aafe96bbf409564bcce653d58fffb40cf":[10,8,7,42,2],
+"structspa__param__info.html#ad470ae46aca7e354753efbb1019f34fe":[10,8,7,42,0],
+"structspa__param__info.html#afcbe452106c79a62cc457da5a19eafcb":[10,8,7,42,3],
 "structspa__plugin__loader.html":[10,8,9,6,1],
 "structspa__plugin__loader.html#a17501870cdaf04804cde83d541a31a61":[10,8,9,6,1,0],
 "structspa__plugin__loader__methods.html":[10,8,9,6,2],
@@ -145,12 +187,12 @@ var NAVTREEINDEX22 =
 "structspa__port__info.html#a3f9832799f2903cdd623d71f958fbc5c":[10,8,6,20,3],
 "structspa__port__info.html#a81b330b23307447d948209a19d7a8aee":[10,8,6,20,0],
 "structspa__port__info.html#ab6581ff27cf6d9cc624283ba6beed837":[10,8,6,20,4],
-"structspa__process__latency__info.html":[10,8,7,39],
-"structspa__process__latency__info.html#a1e891c0385d3fb6840019255e4a7bc7f":[10,8,7,39,0],
-"structspa__process__latency__info.html#a93fac86cdd1aca91cc5e57a5ea0340fb":[10,8,7,39,1],
-"structspa__process__latency__info.html#a97e2de30ab39d818003af3e303049801":[10,8,7,39,2],
+"structspa__process__latency__info.html":[10,8,7,41],
+"structspa__process__latency__info.html#a1e891c0385d3fb6840019255e4a7bc7f":[10,8,7,41,0],
+"structspa__process__latency__info.html#a93fac86cdd1aca91cc5e57a5ea0340fb":[10,8,7,41,1],
+"structspa__process__latency__info.html#a97e2de30ab39d818003af3e303049801":[10,8,7,41,2],
 "structspa__ratelimit.html":[11,0,276],
-"structspa__ratelimit.html#a2569e6c7d90ae29e43801dc9eb889316":[11,0,276,4],
+"structspa__ratelimit.html#a45159c1daa14dddd0e911cbbbac0467f":[11,0,276,4],
 "structspa__ratelimit.html#a54120e58d9dbe2d34bd6c4d217a23030":[11,0,276,0],
 "structspa__ratelimit.html#a9b0862c9c1b74066994419ce0957b43b":[11,0,276,1],
 "structspa__ratelimit.html#af29b16a4c28de3a2503ae1302dba9ff7":[11,0,276,2],
@@ -207,47 +249,5 @@ var NAVTREEINDEX22 =
 "structspa__system__methods.html#a448396798797647ebbf458fca65ef189":[10,8,9,7,3,12],
 "structspa__system__methods.html#a4a677665cdba24ec2faf6f471a919fa6":[10,8,9,7,3,17],
 "structspa__system__methods.html#a4cb1d67e7262f881d36b5c8a25f4d485":[10,8,9,7,3,16],
-"structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060":[10,8,9,7,3,1],
-"structspa__system__methods.html#a56a305f758899158e90920cf28fd41e4":[10,8,9,7,3,0],
-"structspa__system__methods.html#a74ee473681fb6c5c83693d2be53f18db":[10,8,9,7,3,6],
-"structspa__system__methods.html#a7a30db95034f05fd2c8c41e78342d500":[10,8,9,7,3,15],
-"structspa__system__methods.html#a81c5752082d2ee1f392fe3ae914d7f37":[10,8,9,7,3,4],
-"structspa__system__methods.html#a9288a8dd07cf29166a03829e07eb1718":[10,8,9,7,3,7],
-"structspa__system__methods.html#a97bdbd157cd2ff98a0ab09b85522960c":[10,8,9,7,3,5],
-"structspa__system__methods.html#a9905a87c5474f3a7a6b547999bc7cc7c":[10,8,9,7,3,2],
-"structspa__system__methods.html#aae7a5c2f44c9015e351032066498d247":[10,8,9,7,3,8],
-"structspa__system__methods.html#abd9d8195afc746c4ef19428491fe00fa":[10,8,9,7,3,14],
-"structspa__system__methods.html#abea413fdeedbae46e481fb1c698b81b8":[10,8,9,7,3,19],
-"structspa__system__methods.html#ada4083f64959db28b4a03f4032ee87e9":[10,8,9,7,3,13],
-"structspa__system__methods.html#adfaee480ca6869161824c85928c0e3d0":[10,8,9,7,3,9],
-"structspa__system__methods.html#aea9a9e0adc213e0090a50e3b4883db77":[10,8,9,7,3,3],
-"structspa__thread.html":[10,8,9,8,3],
-"structspa__thread__utils.html":[10,8,9,8,1],
-"structspa__thread__utils.html#add4d911915f7c8e76b9c646389facf70":[10,8,9,8,1,0],
-"structspa__thread__utils__methods.html":[10,8,9,8,2],
-"structspa__thread__utils__methods.html#a3324347184f8b1caa930012817982c41":[10,8,9,8,2,5],
-"structspa__thread__utils__methods.html#a68878e9b02ee15f3590d4c871a97d74a":[10,8,9,8,2,0],
-"structspa__thread__utils__methods.html#aa0c4c049d9406510ff457400df373ceb":[10,8,9,8,2,1],
-"structspa__thread__utils__methods.html#aa5a251e895f44dd6f48ee3014f0546e4":[10,8,9,8,2,3],
-"structspa__thread__utils__methods.html#ab1126024161570f88d077ecee01066e8":[10,8,9,8,2,2],
-"structspa__thread__utils__methods.html#adaa8eb3e63f991d91dbb6246fd4f6c3e":[10,8,9,8,2,4],
-"structspa__type__info.html":[10,8,8,12,2],
-"structspa__type__info.html#a25dfe56fe53d756509cd5daa5f5b64e5":[10,8,8,12,2,0],
-"structspa__type__info.html#ab94f9983f18d62536d03ba5eb7db9bae":[10,8,8,12,2,1],
-"structspa__type__info.html#afedc2465e18bf4d93bf2a3d8afcc4c13":[10,8,8,12,2,2],
-"structspa__video__colorimetry.html":[10,8,7,41],
-"structspa__video__colorimetry.html#a59be293b53b9bda54a7e3269facb1cf2":[10,8,7,41,0],
-"structspa__video__colorimetry.html#aa2b220b0a2586562f3547505f851fd21":[10,8,7,41,1],
-"structspa__video__colorimetry.html#aba452a4ed2b7424b2399971e8c1444bb":[10,8,7,41,2],
-"structspa__video__colorimetry.html#ae40f82c41e61be82a9697a872d83479e":[10,8,7,41,3],
-"structspa__video__info.html":[10,8,7,43],
-"structspa__video__info.html#a0e442291121d1e295e2db47ead38eb11":[10,8,7,43,5],
-"structspa__video__info.html#a2b4797467940061e93ad79cbdbb9e928":[10,8,7,43,6],
-"structspa__video__info.html#a429e55f4dde148559d032bcaf8cd73f0":[10,8,7,43,1],
-"structspa__video__info.html#a697a0106c54d5680d0cfd2731b60d712":[10,8,7,43,2],
-"structspa__video__info.html#a73d52ad69db77b05afa52a8cb61455c9":[10,8,7,43,0],
-"structspa__video__info.html#ab2856db92b8c85f902b4be0390dd2141":[10,8,7,43,4],
-"structspa__video__info.html#afe7b9fde171f232f0b7eb76778845784":[10,8,7,43,3],
-"structspa__video__info__dsp.html":[10,8,7,42],
-"structspa__video__info__dsp.html#a634c0bd50f00f704f39e255f25785338":[10,8,7,42,1]
+"structspa__system__methods.html#a4cd27e2c3a8daa1705da0028af779060":[10,8,9,7,3,1]
 };
