@@ -177,7 +177,7 @@ var searchData=
   ['spa_5fpod_5fbuilder_5fbool_174',['spa_pod_builder_bool',['../group__spa__pod.html#ga929573f096e90d4aa11d14e1527d2d63',1,'builder.h']]],
   ['spa_5fpod_5fbuilder_5fbytes_175',['spa_pod_builder_bytes',['../group__spa__pod.html#gab76a5f13f125ca2610906f28e1961b3c',1,'builder.h']]],
   ['spa_5fpod_5fbuilder_5fchild_176',['spa_pod_builder_child',['../group__spa__pod.html#ga204d1a47391802a5c04f2def9bbe919a',1,'builder.h']]],
-  ['spa_5fpod_5fbuilder_5fcontrol_177',['spa_pod_builder_control',['../group__spa__pod.html#ga82e4fb3f51ce8215e63bfb0eefc812e9',1,'builder.h']]],
+  ['spa_5fpod_5fbuilder_5fcontrol_177',['spa_pod_builder_control',['../group__spa__pod.html#ga7e2695ed7013bdf6791e692e3c726452',1,'builder.h']]],
   ['spa_5fpod_5fbuilder_5fderef_178',['spa_pod_builder_deref',['../group__spa__pod.html#gaf08245bcd5bb244e6ea3d7520b4a665c',1,'builder.h']]],
   ['spa_5fpod_5fbuilder_5fdouble_179',['spa_pod_builder_double',['../group__spa__pod.html#ga4059b7055950c4100924cf9bc2b4e23f',1,'builder.h']]],
   ['spa_5fpod_5fbuilder_5ffd_180',['spa_pod_builder_fd',['../group__spa__pod.html#ga500437e7eb44b8c952651347fb6c9af9',1,'builder.h']]],
@@ -308,10 +308,10 @@ var searchData=
   ['spa_5fringbuffer_5fget_5fread_5findex_305',['spa_ringbuffer_get_read_index',['../group__spa__ringbuffer.html#gaa7b051ad6a9926f26522dda14555aa9e',1,'ringbuffer.h']]],
   ['spa_5fringbuffer_5fget_5fwrite_5findex_306',['spa_ringbuffer_get_write_index',['../group__spa__ringbuffer.html#gae84a3778b64a5e9dbccb8f75b50e3f99',1,'ringbuffer.h']]],
   ['spa_5fringbuffer_5finit_307',['spa_ringbuffer_init',['../group__spa__ringbuffer.html#ga23b552aedb20b289ff75899644363a15',1,'ringbuffer.h']]],
-  ['spa_5fringbuffer_5fread_5fdata_308',['spa_ringbuffer_read_data',['../group__spa__ringbuffer.html#ga9e1d1b2a0c6d169ee9388a765c07b698',1,'ringbuffer.h']]],
+  ['spa_5fringbuffer_5fread_5fdata_308',['spa_ringbuffer_read_data',['../group__spa__ringbuffer.html#ga2e55c1d2e6fc8f11ae921ab54c6c4829',1,'ringbuffer.h']]],
   ['spa_5fringbuffer_5fread_5fupdate_309',['spa_ringbuffer_read_update',['../group__spa__ringbuffer.html#ga3fc30da551d1d6b3e29d875380b3e57e',1,'ringbuffer.h']]],
   ['spa_5fringbuffer_5fset_5favail_310',['spa_ringbuffer_set_avail',['../group__spa__ringbuffer.html#ga21c5ca3c2ac3c75f19c39e2dfef3611a',1,'ringbuffer.h']]],
-  ['spa_5fringbuffer_5fwrite_5fdata_311',['spa_ringbuffer_write_data',['../group__spa__ringbuffer.html#gadaacf8c44d93c41c4e6e34b1df310fd3',1,'ringbuffer.h']]],
+  ['spa_5fringbuffer_5fwrite_5fdata_311',['spa_ringbuffer_write_data',['../group__spa__ringbuffer.html#ga9fa1f1070b14a85a4898f578a6bc9171',1,'ringbuffer.h']]],
   ['spa_5fringbuffer_5fwrite_5fupdate_312',['spa_ringbuffer_write_update',['../group__spa__ringbuffer.html#ga855a555fdb8afc184899dffbae165f82',1,'ringbuffer.h']]],
   ['spa_5fscnprintf_313',['spa_scnprintf',['../group__spa__string.html#gae194d9bc956defbfe180dc658e3df052',1,'string.h']]],
   ['spa_5fstrbuf_5fappend_314',['spa_strbuf_append',['../group__spa__string.html#ga921ebca10b8f1bacd31e159f11e96288',1,'string.h']]],
@@ -323,11 +323,18 @@ var searchData=
   ['spa_5fstrtod_320',['spa_strtod',['../group__spa__string.html#ga0faf9c1cc2f41796a16399193bbdb263',1,'string.h']]],
   ['spa_5fstrtof_321',['spa_strtof',['../group__spa__string.html#ga928368a5adc237123fe3097ddf09061d',1,'string.h']]],
   ['spa_5fsupport_5ffind_322',['spa_support_find',['../group__spa__handle.html#ga82f1b02dfb782a24ed624e16392b1e12',1,'plugin.h']]],
-  ['spa_5fthread_5futils_5facquire_5frt_323',['spa_thread_utils_acquire_rt',['../group__spa__thread.html#ga087f55566e08c2bb1536574b7556a66f',1,'thread.h']]],
-  ['spa_5fthread_5futils_5fcreate_324',['spa_thread_utils_create',['../group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41',1,'thread.h']]],
-  ['spa_5fthread_5futils_5fdrop_5frt_325',['spa_thread_utils_drop_rt',['../group__spa__thread.html#gae1224b4702957d8a48f7c17cf350f5a2',1,'thread.h']]],
-  ['spa_5fthread_5futils_5fget_5frt_5frange_326',['spa_thread_utils_get_rt_range',['../group__spa__thread.html#ga13cf7d6799ad80fe7e3f69874032d529',1,'thread.h']]],
-  ['spa_5fthread_5futils_5fjoin_327',['spa_thread_utils_join',['../group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43',1,'thread.h']]],
-  ['spa_5ftype_5fis_5fa_328',['spa_type_is_a',['../group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3',1,'type-info.h']]],
-  ['spa_5fvscnprintf_329',['spa_vscnprintf',['../group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6',1,'string.h']]]
+  ['spa_5ftag_5fbuild_5fadd_5fdict_323',['spa_tag_build_add_dict',['../group__spa__param.html#ga26332db17a2bed2c5c31e5caede8abd9',1,'tag-utils.h']]],
+  ['spa_5ftag_5fbuild_5fadd_5finfo_324',['spa_tag_build_add_info',['../group__spa__param.html#ga1602a3816a886eeab96eb1ab406716cb',1,'tag-utils.h']]],
+  ['spa_5ftag_5fbuild_5fend_325',['spa_tag_build_end',['../group__spa__param.html#gaa8449e57ee4b6dcbb10b4c50bfe1ece3',1,'tag-utils.h']]],
+  ['spa_5ftag_5fbuild_5fstart_326',['spa_tag_build_start',['../group__spa__param.html#ga74e9b5d6d1fbb7e80ed057205c8de6de',1,'tag-utils.h']]],
+  ['spa_5ftag_5fcompare_327',['spa_tag_compare',['../group__spa__param.html#ga2a103e1a6794f27fe3c0b3b8d08f28d2',1,'tag-utils.h']]],
+  ['spa_5ftag_5finfo_5fparse_328',['spa_tag_info_parse',['../group__spa__param.html#ga6fe291b7706101915cde605fc59d26a8',1,'tag-utils.h']]],
+  ['spa_5ftag_5fparse_329',['spa_tag_parse',['../group__spa__param.html#ga673a6e3bccba9de900282c09b882a87d',1,'tag-utils.h']]],
+  ['spa_5fthread_5futils_5facquire_5frt_330',['spa_thread_utils_acquire_rt',['../group__spa__thread.html#ga087f55566e08c2bb1536574b7556a66f',1,'thread.h']]],
+  ['spa_5fthread_5futils_5fcreate_331',['spa_thread_utils_create',['../group__spa__thread.html#ga7c5acfdece976cd3f7b12dee4ddb3e41',1,'thread.h']]],
+  ['spa_5fthread_5futils_5fdrop_5frt_332',['spa_thread_utils_drop_rt',['../group__spa__thread.html#gae1224b4702957d8a48f7c17cf350f5a2',1,'thread.h']]],
+  ['spa_5fthread_5futils_5fget_5frt_5frange_333',['spa_thread_utils_get_rt_range',['../group__spa__thread.html#ga13cf7d6799ad80fe7e3f69874032d529',1,'thread.h']]],
+  ['spa_5fthread_5futils_5fjoin_334',['spa_thread_utils_join',['../group__spa__thread.html#ga8dcf8fcd02dbf3c2c49afe37e40b6a43',1,'thread.h']]],
+  ['spa_5ftype_5fis_5fa_335',['spa_type_is_a',['../group__spa__types.html#ga35e8b94254c7e556e3838eb8ab5167c3',1,'type-info.h']]],
+  ['spa_5fvscnprintf_336',['spa_vscnprintf',['../group__spa__string.html#gab9f2fbcc3c33f77f37e9f00941f387b6',1,'string.h']]]
 ];
